==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_front/spec/spec_helper.rb <==
# -*- coding: utf-8 -*-
# This file is copied to ~/spec when you run 'ruby script/generate rspec'
# from the project root directory.
ENV["RAILS_ENV"] = "test"
require File.expand_path(File.dirname(__FILE__) + "/../config/environment")
require 'spec'
require 'spec/autorun'
require 'spec/rails'
# require 'tmpdir'
# require 'fileutils'

Spec::Runner.configure do |config|
  # If you're not using ActiveRecord you should remove these
  # lines, delete config/database.yml and disable :active_record
  # in your config/boot.rb
  config.use_transactional_fixtures = true
  config.use_instantiated_fixtures  = false
  config.fixture_path = RAILS_ROOT + '/test/fixtures/'

  # Set default locale with 'ja' before each test.
  require 'i18n'

  config.before(:each) do
    # Locale.default = "ja-JP"
    I18n.locale = 'ja'
  end

  # == Fixtures
  #
  # You can declare fixtures for each example_group like this:
  #   describe "...." do
  #     fixtures :table_a, :table_b
  #
  # Alternatively, if you prefer to declare them only once, you can
  # do so right here. Just uncomment the next line and replace the fixture
  # names with your fixtures.
  #
  # config.global_fixtures = :goldberg_content_pages, :goldberg_controller_actions,
  #   :goldberg_permissions, :goldberg_roles, :goldberg_roles_permissions,
  #   :goldberg_site_controllers, :goldberg_system_settings, :goldberg_users

  #
  # If you declare global fixtures, be aware that they will be declared
  # for all of your examples, even those that don't use them.
  #
  # You can also declare which fixtures to use (for example fixtures for test/fixtures):
  #
  # config.fixture_path = RAILS_ROOT + '/spec/fixtures/'
  #
  # == Mock Framework
  #
  # RSpec uses it's own mocking framework by default. If you prefer to
  # use mocha, flexmock or RR, uncomment the appropriate line:
  #
  # config.mock_with :mocha
  # config.mock_with :flexmock
  # config.mock_with :rr
  #
  # == Notes
  #
  # For more information take a look at Spec::Runner::Configuration and Spec::Runner
end

def config_override_root(config_name, path = "app/views/cms")
  # テスト中にec_frontの内容を書き換えるわけには行かないので、tmpdirを対象とします。
  tmp_dir = File.join(Dir.tmpdir, "test_#{config_name.to_s}")
  FileUtils.instance_eval do
    rm_rf(tmp_dir) if File.exist?(tmp_dir)
    mkdir_p(File.join(tmp_dir, *path.split('/')))
  end
  original_root = EcRider.config.send(config_name)

  EcRider.config.override(config_name, tmp_dir) do
    yield(tmp_dir)
  end

  EcRider.config.send(config_name).should == original_root
end

def config_override_ec_front_root(&block)
  config_override_root(:ec_front_root, &block)
end

def config_override_ec_admin_root(&block)
  config_override_root(:ec_admin_root, &block)
end


DirFixtures.define("test/fixtures/ec_front/publics") do |d|
  d.target File.expand_path(File.join(EcRider.config.ec_front_root, 'public'))
  d.backup_cache true
  d.backup_dir "tmp/ec_front_public"

  d.protect %w(.gitignore favicon.ico robots.txt)
  d.protect 'ec_rider'
  d.protect 'projects/1'
  FileUtils.mkdir_p(d.backup_dir)
end


require "nkf"

# convert $stdout to sjis only command prompt at Windows
if !defined?($stdout.old_write_for_sjis_filter) &&
    RUBY_PLATFORM =~ /win32/ && ENV['TERM'].nil?
  class << $stdout
    alias :old_write_for_sjis_filter :write
    def write(str)
      # change to sjis AS IS
      old_write_for_sjis_filter NKF.nkf('-sxm0', str.to_s)
    end
  end
#  puts "overrode $stdout.write"
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_front/spec/spec_helper.rb <==
# -*- coding: utf-8 -*-
# This file is copied to ~/spec when you run 'ruby script/generate rspec'
# from the project root directory.
ENV["RAILS_ENV"] = "test"
require File.expand_path(File.dirname(__FILE__) + "/../config/environment")
require 'spec'
require 'spec/autorun'
require 'spec/rails'
# require 'tmpdir'
# require 'fileutils'


Spec::Runner.configure do |config|
  # If you're not using ActiveRecord you should remove these
  # lines, delete config/database.yml and disable :active_record
  # in your config/boot.rb
  config.use_transactional_fixtures = true
  config.use_instantiated_fixtures  = false
  config.fixture_path = RAILS_ROOT + '/test/fixtures/'

  # Set default locale with 'ja' before each test.
  require 'i18n'

  config.before(:each) do
    # Locale.default = "ja-JP"
    I18n.locale = 'ja'
  end

  # == Fixtures
  #
  # You can declare fixtures for each example_group like this:
  #   describe "...." do
  #     fixtures :table_a, :table_b
  #
  # Alternatively, if you prefer to declare them only once, you can
  # do so right here. Just uncomment the next line and replace the fixture
  # names with your fixtures.
  #
  # config.global_fixtures = :goldberg_content_pages, :goldberg_controller_actions,
  #   :goldberg_permissions, :goldberg_roles, :goldberg_roles_permissions,
  #   :goldberg_site_controllers, :goldberg_system_settings, :goldberg_users

  #
  # If you declare global fixtures, be aware that they will be declared
  # for all of your examples, even those that don't use them.
  #
  # You can also declare which fixtures to use (for example fixtures for test/fixtures):
  #
  # config.fixture_path = RAILS_ROOT + '/spec/fixtures/'
  #
  # == Mock Framework
  #
  # RSpec uses it's own mocking framework by default. If you prefer to
  # use mocha, flexmock or RR, uncomment the appropriate line:
  #
  # config.mock_with :mocha
  # config.mock_with :flexmock
  # config.mock_with :rr
  #
  # == Notes
  #
  # For more information take a look at Spec::Runner::Configuration and Spec::Runner
end

def config_override_root(config_name, path = "app/views/cms")
  # テスト中にec_frontの内容を書き換えるわけには行かないので、tmpdirを対象とします。
  tmp_dir = File.join(RAILS_ROOT, "tmp", "test_#{config_name.to_s}")
  FileUtils.instance_eval do
    rm_rf(tmp_dir) if File.exist?(tmp_dir)
    mkdir_p(File.join(tmp_dir, *path.split('/')))
  end
  original_root = EcRider.config.send(config_name)

  EcRider.config.override(config_name, tmp_dir) do
    yield(tmp_dir)
  end

  EcRider.config.send(config_name).should == original_root
end

def config_override_ec_front_root(&block)
  config_override_root(:ec_front_root, &block)
end

def config_override_ec_admin_root(&block)
  config_override_root(:ec_admin_root, &block)
end


unless DirFixtures.definitions.key?("test/fixtures/ec_front/publics")
  DirFixtures.define("test/fixtures/ec_front/publics") do |d|
    d.target File.expand_path(File.join(EcRider.config.ec_front_root, 'public'))
    d.backup_cache true
    d.backup_dir "tmp/ec_front_public"

    d.protect %w(.gitignore favicon.ico robots.txt)
    d.protect 'ec_rider'
    d.protect 'projects/1'
    FileUtils.mkdir_p(d.backup_dir)
  end
end

require "nkf"

# convert $stdout to sjis only command prompt at Windows
if !defined?($stdout.old_write_for_sjis_filter) &&
    RUBY_PLATFORM =~ /win32/ && ENV['TERM'].nil?
  class << $stdout
    alias :old_write_for_sjis_filter :write
    def write(str)
      # change to sjis AS IS
      old_write_for_sjis_filter NKF.nkf('-sxm0', str.to_s)
    end
  end
#  puts "overrode $stdout.write"
end

# 一時的に定数値を置き換えるためのメソッドです。
# 
# === 使用例. ===
#  it 'productionモードかつ環境変数ECR_ENABLE_PASSENGERが設定されている場合、公開チェックを行う。' do
#    with_constants :RAILS_ENV => 'production' do
#      EcRider.config.stub!(:enable_passenger).and_return(true)
#      EcRider::ViewCacheCtrl.should_receive(:published_check).and_return(true)
#      post :index
#      response.should be_success
#    end
#  end
#
def with_constants(constants, &block)
  saved_constants = {}
  constants.each do |constant, val|
    saved_constants[ constant ] = Object.const_get( constant )
    Kernel::silence_warnings { Object.const_set( constant, val ) }
  end

  begin
    block.call
  ensure
    constants.each do |constant, val|
      Kernel::silence_warnings { Object.const_set( constant, saved_constants[ constant ] ) }
    end
  end
end
